@@ -1,14 +1,10 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree;
-$WebService::Braintree::VERSION = '1.5';
+$WebService::Braintree::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
-# These have to be loaded first-er-est because they weren't loaded before.
-use WebService::Braintree::AdvancedSearchFields;
-use WebService::Braintree::AdvancedSearchNodes;
-
 # Load the error codes omnibus so clients can get at them.
 use WebService::Braintree::ErrorCodes;
 
