@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::ClientToken;
-$WebService::Braintree::ClientToken::VERSION = '1.5';
+$WebService::Braintree::ClientToken::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -16,7 +16,7 @@ Mobile and Javascript.
 
 =cut
 
-use Moose;
+use Moo;
 
 with 'WebService::Braintree::Role::Interface';
 
