@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::CreditCard;
-$WebService::Braintree::CreditCard::VERSION = '1.5';
+$WebService::Braintree::CreditCard::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -26,7 +26,7 @@ This class creates, updates, deletes, and finds credit cards.
 
 =cut
 
-use Moose;
+use Moo;
 
 with 'WebService::Braintree::Role::Interface';
 
