@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::Dispute;
-$WebService::Braintree::Dispute::VERSION = '1.5';
+$WebService::Braintree::Dispute::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -19,7 +19,7 @@ use WebService::Braintree::Dispute::Kind;
 use WebService::Braintree::Dispute::Reason;
 use WebService::Braintree::Dispute::Status;
 
-use Moose;
+use Moo;
 
 with 'WebService::Braintree::Role::Interface';
 
