@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::PaginatedCollection;
-$WebService::Braintree::PaginatedCollection::VERSION = '1.5';
+$WebService::Braintree::PaginatedCollection::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -18,7 +18,7 @@ This class will only be created as part of a L<response|WebService::Braintree::R
 
 =cut
 
-use Moose;
+use Moo;
 
 =head1 METHODS
 
