@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::SubscriptionSearch;
-$WebService::Braintree::SubscriptionSearch::VERSION = '1.5';
+$WebService::Braintree::SubscriptionSearch::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -18,8 +18,10 @@ objects of this class through the search interface.
 
 =cut
 
-use Moose;
-extends 'WebService::Braintree::AdvancedSearch';
+use Moo;
+with 'WebService::Braintree::Role::AdvancedSearch';
+
+use constant FIELDS => [];
 
 use WebService::Braintree::Subscription::Status;
 
@@ -27,15 +29,13 @@ use WebService::Braintree::Subscription::Status;
 
 =cut
 
-my $field = WebService::Braintree::AdvancedSearchFields->new(metaclass => __PACKAGE__->meta);
-
 =head2 address_country_name
 
 This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">. It will restrict the search to a specific country name.
 
 =cut
 
-$field->text('address_country_name');
+__PACKAGE__->text_field('address_country_name');
 
 =head2 billing_cycles_remaining
 
@@ -43,7 +43,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range('billing_cycles_remaining');
+__PACKAGE__->range_field('billing_cycles_remaining');
 
 =head2 days_past_due
 
@@ -51,7 +51,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range('days_past_due');
+__PACKAGE__->range_field('days_past_due');
 
 =head2 id
 
@@ -59,7 +59,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text('id');
+__PACKAGE__->text_field('id');
 
 =head2 ids
 
@@ -67,7 +67,7 @@ This is a L<multiple-values field|WebService::Braintree::AdvancedSearchNodes/"Mu
 
 =cut
 
-$field->multiple_values('ids');
+__PACKAGE__->multiple_values_field('ids');
 
 =head2 in_trial_period
 
@@ -75,7 +75,7 @@ This is a L<multiple-values field|WebService::Braintree::AdvancedSearchNodes/"Mu
 
 =cut
 
-$field->multiple_values('in_trial_period');
+__PACKAGE__->multiple_values_field('in_trial_period');
 
 =head2 merchant_account_id
 
@@ -83,7 +83,7 @@ This is a L<multiple-values field|WebService::Braintree::AdvancedSearchNodes/"Mu
 
 =cut
 
-$field->multiple_values('merchant_account_id');
+__PACKAGE__->multiple_values_field('merchant_account_id');
 
 =head2 next_billing_date
 
@@ -91,7 +91,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range('next_billing_date');
+__PACKAGE__->range_field('next_billing_date');
 
 =head2 plan_id
 
@@ -99,7 +99,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text('plan_id');
+__PACKAGE__->text_field('plan_id');
 
 =head2 price
 
@@ -107,7 +107,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range('price');
+__PACKAGE__->range_field('price');
 
 =head2 status
 
@@ -117,7 +117,7 @@ This list is restricted to the values defined by L<WebService::Braintree::Subscr
 
 =cut
 
-$field->multiple_values('status', WebService::Braintree::Subscription::Status::All);
+__PACKAGE__->multiple_values_field('status', WebService::Braintree::Subscription::Status::All);
 
 =head2 transaction_id
 
@@ -125,7 +125,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text('transaction_id');
+__PACKAGE__->text_field('transaction_id');
 
 __PACKAGE__->meta->make_immutable;
 
