@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::TransactionSearch;
-$WebService::Braintree::TransactionSearch::VERSION = '1.5';
+$WebService::Braintree::TransactionSearch::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -18,8 +18,10 @@ objects of this class through the search interface.
 
 =cut
 
-use Moose;
-extends 'WebService::Braintree::AdvancedSearch';
+use Moo;
+with 'WebService::Braintree::Role::AdvancedSearch';
+
+use constant FIELDS => [];
 
 use WebService::Braintree::Transaction::Status;
 
@@ -27,15 +29,13 @@ use WebService::Braintree::Transaction::Status;
 
 =cut
 
-my $field = WebService::Braintree::AdvancedSearchFields->new(metaclass => __PACKAGE__->meta);
-
 =head2 amount
 
 This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field">. It will restrict the search to subscriptions created between the two values.
 
 =cut
 
-$field->range("amount");
+__PACKAGE__->range_field("amount");
 
 =head2 authorization_expired_at
 
@@ -43,7 +43,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("authorization_expired_at");
+__PACKAGE__->range_field("authorization_expired_at");
 
 =head2 authorized_at
 
@@ -51,7 +51,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("authorized_at");
+__PACKAGE__->range_field("authorized_at");
 
 =head2 billing_company
 
@@ -59,7 +59,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_company");
+__PACKAGE__->text_field("billing_company");
 
 =head2 billing_country_name
 
@@ -67,7 +67,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_country_name");
+__PACKAGE__->text_field("billing_country_name");
 
 =head2 billing_extended_address
 
@@ -75,7 +75,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_extended_address");
+__PACKAGE__->text_field("billing_extended_address");
 
 =head2 billing_first_name
 
@@ -83,7 +83,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_first_name");
+__PACKAGE__->text_field("billing_first_name");
 
 =head2 billing_last_name
 
@@ -91,7 +91,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_last_name");
+__PACKAGE__->text_field("billing_last_name");
 
 =head2 billing_locality
 
@@ -99,7 +99,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_locality");
+__PACKAGE__->text_field("billing_locality");
 
 =head2 billing_postal_code
 
@@ -107,7 +107,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_postal_code");
+__PACKAGE__->text_field("billing_postal_code");
 
 =head2 billing_region
 
@@ -115,7 +115,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_region");
+__PACKAGE__->text_field("billing_region");
 
 =head2 billing_street_address
 
@@ -123,7 +123,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("billing_street_address");
+__PACKAGE__->text_field("billing_street_address");
 
 =head2 created_at
 
@@ -131,7 +131,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("created_at");
+__PACKAGE__->range_field("created_at");
 
 =head2 created_using
 
@@ -141,7 +141,7 @@ This list is restricted to the values defined by L<WebService::Braintree::Transa
 
 =cut
 
-$field->multiple_values("created_using", WebService::Braintree::Transaction::CreatedUsing->All);
+__PACKAGE__->multiple_values_field("created_using", WebService::Braintree::Transaction::CreatedUsing->All);
 
 =head2 credit_card_cardholder_name
 
@@ -149,7 +149,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("credit_card_cardholder_name");
+__PACKAGE__->text_field("credit_card_cardholder_name");
 
 =head2 credit_card_customer_location
 
@@ -159,7 +159,7 @@ This list is restricted to the values defined by L<WebService::Braintree::Credit
 
 =cut
 
-$field->multiple_values("credit_card_customer_location", WebService::Braintree::CreditCard::Location->All);
+__PACKAGE__->multiple_values_field("credit_card_customer_location", WebService::Braintree::CreditCard::Location->All);
 
 =head2 credit_card_expiration_date
 
@@ -168,7 +168,7 @@ credit cards with a specific expiration date.
 
 =cut
 
-$field->equality("credit_card_expiration_date");
+__PACKAGE__->equality_field("credit_card_expiration_date");
 
 =head2 credit_card_number
 
@@ -177,7 +177,7 @@ credit cards containing a specific card number.
 
 =cut
 
-$field->partial_match("credit_card_number");
+__PACKAGE__->partial_match_field("credit_card_number");
 
 =head2 credit_card_card_type
 
@@ -187,7 +187,7 @@ This list is restricted to the values defined by L<WebService::Braintree::Credit
 
 =cut
 
-$field->multiple_values("credit_card_card_type", WebService::Braintree::CreditCard::CardType->All);
+__PACKAGE__->multiple_values_field("credit_card_card_type", WebService::Braintree::CreditCard::CardType->All);
 
 =head2 currency
 
@@ -195,7 +195,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("currency");
+__PACKAGE__->text_field("currency");
 
 =head2 customer_company
 
@@ -203,7 +203,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_company");
+__PACKAGE__->text_field("customer_company");
 
 =head2 customer_email
 
@@ -211,7 +211,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_email");
+__PACKAGE__->text_field("customer_email");
 
 =head2 customer_fax
 
@@ -219,7 +219,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_fax");
+__PACKAGE__->text_field("customer_fax");
 
 =head2 customer_first_name
 
@@ -227,7 +227,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_first_name");
+__PACKAGE__->text_field("customer_first_name");
 
 =head2 customer_id
 
@@ -235,7 +235,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_id");
+__PACKAGE__->text_field("customer_id");
 
 =head2 customer_last_name
 
@@ -243,7 +243,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_last_name");
+__PACKAGE__->text_field("customer_last_name");
 
 =head2 customer_phone
 
@@ -251,7 +251,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_phone");
+__PACKAGE__->text_field("customer_phone");
 
 =head2 customer_website
 
@@ -259,7 +259,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("customer_website");
+__PACKAGE__->text_field("customer_website");
 
 =head2 failed_at
 
@@ -267,7 +267,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("failed_at");
+__PACKAGE__->range_field("failed_at");
 
 =head2 gateway_rejected_at
 
@@ -275,7 +275,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("gateway_rejected_at");
+__PACKAGE__->range_field("gateway_rejected_at");
 
 =head2 id
 
@@ -283,7 +283,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("id");
+__PACKAGE__->text_field("id");
 
 =head2 ids
 
@@ -291,7 +291,7 @@ This is a L<multiple-values field|WebService::Braintree::AdvancedSearchNodes/"Mu
 
 =cut
 
-$field->multiple_values("ids");
+__PACKAGE__->multiple_values_field("ids");
 
 =head2 merchant_account_id
 
@@ -299,7 +299,7 @@ This is a L<multiple-values field|WebService::Braintree::AdvancedSearchNodes/"Mu
 
 =cut
 
-$field->multiple_values("merchant_account_id");
+__PACKAGE__->multiple_values_field("merchant_account_id");
 
 =head2 order_id
 
@@ -307,7 +307,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("order_id");
+__PACKAGE__->text_field("order_id");
 
 =head2 payment_method_token
 
@@ -315,7 +315,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("payment_method_token");
+__PACKAGE__->text_field("payment_method_token");
 
 =head2 paypal_payment_id
 
@@ -323,7 +323,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("paypal_payment_id");
+__PACKAGE__->text_field("paypal_payment_id");
 
 =head2 paypal_authorization_id
 
@@ -331,7 +331,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("paypal_authorization_id");
+__PACKAGE__->text_field("paypal_authorization_id");
 
 =head2 paypal_payer_email
 
@@ -339,7 +339,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("paypal_payer_email");
+__PACKAGE__->text_field("paypal_payer_email");
 
 =head2 processor_authorization_code
 
@@ -347,7 +347,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("processor_authorization_code");
+__PACKAGE__->text_field("processor_authorization_code");
 
 =head2 processor_declined_at
 
@@ -355,7 +355,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("processor_declined_at");
+__PACKAGE__->range_field("processor_declined_at");
 
 =head2 refund
 
@@ -363,7 +363,7 @@ This is a L<key-value field|WebService::Braintree::AdvancedSearchNodes/"Key Valu
 
 =cut
 
-$field->key_value("refund");
+__PACKAGE__->key_value_field("refund");
 
 =head2 settled_at
 
@@ -371,7 +371,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("settled_at");
+__PACKAGE__->range_field("settled_at");
 
 =head2 settlement_batch_id
 
@@ -379,7 +379,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("settlement_batch_id");
+__PACKAGE__->text_field("settlement_batch_id");
 
 =head2 shipping_company
 
@@ -387,7 +387,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_company");
+__PACKAGE__->text_field("shipping_company");
 
 =head2 shipping_country_name
 
@@ -395,7 +395,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_country_name");
+__PACKAGE__->text_field("shipping_country_name");
 
 =head2 shipping_extended_address
 
@@ -403,7 +403,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_extended_address");
+__PACKAGE__->text_field("shipping_extended_address");
 
 =head2 shipping_first_name
 
@@ -411,7 +411,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_first_name");
+__PACKAGE__->text_field("shipping_first_name");
 
 =head2 shipping_last_name
 
@@ -419,7 +419,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_last_name");
+__PACKAGE__->text_field("shipping_last_name");
 
 =head2 shipping_locality
 
@@ -427,7 +427,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_locality");
+__PACKAGE__->text_field("shipping_locality");
 
 =head2 shipping_postal_code
 
@@ -435,7 +435,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_postal_code");
+__PACKAGE__->text_field("shipping_postal_code");
 
 =head2 shipping_region
 
@@ -443,7 +443,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_region");
+__PACKAGE__->text_field("shipping_region");
 
 =head2 shipping_street_address
 
@@ -451,7 +451,7 @@ This is a L<text field|WebService::Braintree::AdvancedSearchNodes/"Text Field">.
 
 =cut
 
-$field->text("shipping_street_address");
+__PACKAGE__->text_field("shipping_street_address");
 
 =head2 source
 
@@ -461,7 +461,7 @@ This list is restricted to the values defined by L<WebService::Braintree::Transa
 
 =cut
 
-$field->multiple_values("source", WebService::Braintree::Transaction::Source->All);
+__PACKAGE__->multiple_values_field("source", WebService::Braintree::Transaction::Source->All);
 
 =head2 status
 
@@ -471,7 +471,7 @@ This list is restricted to the values defined by L<WebService::Braintree::Transa
 
 =cut
 
-$field->multiple_values("status", WebService::Braintree::Transaction::Status->All);
+__PACKAGE__->multiple_values_field("status", WebService::Braintree::Transaction::Status->All);
 
 =head2 submitted_for_settlement_at
 
@@ -479,7 +479,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("submitted_for_settlement_at");
+__PACKAGE__->range_field("submitted_for_settlement_at");
 
 =head2 ids
 
@@ -489,7 +489,7 @@ This list is restricted to the values defined by L<WebService::Braintree::Transa
 
 =cut
 
-$field->multiple_values("type", WebService::Braintree::Transaction::Type->All);
+__PACKAGE__->multiple_values_field("type", WebService::Braintree::Transaction::Type->All);
 
 =head2 voided_at
 
@@ -497,7 +497,7 @@ This is a L<range field|WebService::Braintree::AdvancedSearchNodes/"Range Field"
 
 =cut
 
-$field->range("voided_at");
+__PACKAGE__->range_field("voided_at");
 
 __PACKAGE__->meta->make_immutable;
 
