@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::TransparentRedirect;
-$WebService::Braintree::TransparentRedirect::VERSION = '1.5';
+$WebService::Braintree::TransparentRedirect::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -19,7 +19,7 @@ TODO
 
 =cut
 
-use Moose;
+use Moo;
 
 with 'WebService::Braintree::Role::Interface';
 
