@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::WebhookNotification;
-$WebService::Braintree::WebhookNotification::VERSION = '1.5';
+$WebService::Braintree::WebhookNotification::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -23,7 +23,7 @@ object or provides a verification of it.
 
 use WebService::Braintree::WebhookNotification::Kind;
 
-use Moose;
+use Moo;
 
 with 'WebService::Braintree::Role::Interface';
 
