@@ -1,11 +1,11 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::WebhookTesting;
-$WebService::Braintree::WebhookTesting::VERSION = '1.5';
+$WebService::Braintree::WebhookTesting::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
-use Moose;
+use Moo;
 
 with 'WebService::Braintree::Role::Interface';
 
