@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::_::CreditCardVerification;
-$WebService::Braintree::_::CreditCardVerification::VERSION = '1.5';
+$WebService::Braintree::_::CreditCardVerification::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -17,11 +17,16 @@ This class will only be created as part of a L<response|WebService::Braintree::R
 
 =cut
 
-use Moose;
-use MooseX::Aliases;
+use Moo;
+use MooX::Aliases;
 
 extends 'WebService::Braintree::_';
 
+use WebService::Braintree::Types qw(
+    Address
+    CreditCard
+);
+
 =head1 ATTRIBUTES
 
 =cut
@@ -78,7 +83,7 @@ C<< billing_address() >> is an alias to this attribute.
 
 has billing => (
     is => 'ro',
-    isa => 'WebService::Braintree::_::Address',
+    isa => Address,
     coerce => 1,
     alias => 'billing_address',
 );
@@ -103,7 +108,7 @@ object of type L<WebService::Braintree::_::CreditCard/>.
 
 has credit_card => (
     is => 'ro',
-    isa => 'WebService::Braintree::_::CreditCard',
+    isa => CreditCard,
     coerce => 1,
 );
 
