@@ -1,11 +1,11 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::_::Subscription::StatusDetail;
-$WebService::Braintree::_::Subscription::StatusDetail::VERSION = '1.5';
+$WebService::Braintree::_::Subscription::StatusDetail::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
-use Moose;
+use Moo;
 
 =head1 NAME
 
