@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::_::ThreeDSecureInfo;
-$WebService::Braintree::_::ThreeDSecureInfo::VERSION = '1.5';
+$WebService::Braintree::_::ThreeDSecureInfo::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -17,8 +17,8 @@ This class will only be created as part of a L<response|WebService::Braintree::R
 
 =cut
 
-use Moose;
-use MooseX::Aliases;
+use Moo;
+use MooX::Aliases;
 
 extends 'WebService::Braintree::_';
 
@@ -32,7 +32,7 @@ C<< is_enrolled() >> is an alias to this attribute.
 
 has enrolled => (
     is => 'ro',
-    alias => 'is_liability_shifted',
+    alias => 'is_enrolled',
 );
 
 =head2 liability_shifted()
