@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::_::Transaction::AddressDetail;
-$WebService::Braintree::_::Transaction::AddressDetail::VERSION = '1.5';
+$WebService::Braintree::_::Transaction::AddressDetail::VERSION = '1.6';
 =head1 NAME
 
 WebService::Braintree::_::Transaction::AddressDetail
@@ -17,7 +17,7 @@ This class will only be created as part of a L<response|WebService::Braintree::R
 use 5.010_001;
 use strictures 1;
 
-use Moose;
+use Moo;
 
 extends 'WebService::Braintree::_';
 
