@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::_::UnknownPaymentMethod;
-$WebService::Braintree::_::UnknownPaymentMethod::VERSION = '1.5';
+$WebService::Braintree::_::UnknownPaymentMethod::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -22,8 +22,8 @@ limited functionality relative to the other payment methods.
 
 =cut
 
-use Moose;
-use MooseX::Aliases;
+use Moo;
+use MooX::Aliases;
 
 extends 'WebService::Braintree::_';
 
