@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::_::VisaCheckoutCard;
-$WebService::Braintree::_::VisaCheckoutCard::VERSION = '1.5';
+$WebService::Braintree::_::VisaCheckoutCard::VERSION = '1.6';
 use 5.010_001;
 use strictures 1;
 
@@ -17,14 +17,17 @@ This class will only be created as part of a L<response|WebService::Braintree::R
 
 =cut
 
-use Moose;
-use MooseX::Aliases;
+use Moo;
+use MooX::Aliases;
 
 extends 'WebService::Braintree::_';
 
-use WebService::Braintree::_::Address;
-use WebService::Braintree::_::CreditCardVerification;
-use WebService::Braintree::_::Subscription;
+use Types::Standard qw(ArrayRef);
+use WebService::Braintree::Types qw(
+    Address
+    CreditCardVerification
+    Subscription
+);
 
 =head1 ATTRIBUTES
 
@@ -39,7 +42,7 @@ L<address|WebService::Braintree::_::Address/>.
 
 has billing_address => (
     is => 'ro',
-    isa => 'WebService::Braintree::_::Address',
+    isa => Address,
     coerce => 1,
 );
 
@@ -278,7 +281,7 @@ L<subscriptions|WebService::Braintree::_::Subscription/>.
 
 has subscriptions => (
     is => 'ro',
-    isa => 'ArrayRefOfSubscription',
+    isa => ArrayRef[Subscription],
     coerce => 1,
 );
 
@@ -321,7 +324,7 @@ L<credit card verifications|WebService::Braintree::_::CreditCardVerification/>.
 
 has verifications => (
     is => 'ro',
-    isa => 'ArrayRefOfCreditCardVerification',
+    isa => ArrayRef[CreditCardVerification],
     coerce => 1,
 );
 
